@@ -27,14 +27,10 @@ __version__ = get_distribution('gcloud-aio-taskqueue').version
 
 from gcloud.aio.taskqueue.queue import PushQueue
 from gcloud.aio.taskqueue.queue import SCOPES
-from gcloud.aio.taskqueue.utils import decode
-from gcloud.aio.taskqueue.utils import encode
 
 
 __all__ = [
     'PushQueue',
     'SCOPES',
     '__version__',
-    'decode',
-    'encode',
 ]
